%
% Peak Measurement, Test routine
%
% author: samuel.dubouloz@cea.fr
%         CEA-LETI - May, 2005
%

clear all,
close all,
clc

%% Signal parameters
dithering   = 0;        % 1 -> dithering, 0 -> no dithering
Tres        = 50e-12;   % Temporal resolution              [s]
BW          = 2e9;      % Signal Bandwidth                 [Hz]
Fc          = 4.1e9;    % Signal center frequency          [Hz]
SigDuration = .01e-3;   % Duration of test dignal          [s]
PRF         = logspace(-2,2,41)*1e6; % PRF values          [Hz]

PRF         = 1e4;

%% Spectrum Analyzer Parameters
RBW         = 3e6;      % Resolution BandWidth             [Hz]
VBW         = 50e6;     % Video Bandwidth (peak meas)      [Hz]

%% Power Limits
AvLimit     = repmat(-41.3, 1, length(PRF));
PkLimit     = repmat(20*log10(RBW/50e6), 1, length(PRF));

%% Average Power (over a 1MHz Bandwidth)
if dithering
    Pa(PRF>0) = -41.3; % Assuming Perfect Dithering
else
    Pa = -41.3 + 10*log10(PRF/1e6);
    Pa(PRF < 1e6) = -41.3;
end

tic
%% Peak Measurement
ww = waitbar(0,'peak measurement...');
for ii = 1:length(PRF),
    waitbar(ii/length(PRF),ww);
    PRP = 1/PRF(ii);
    % Pulse generation
    [t,pulse] = GausPulse(Tres, Fc, BW, PRP);
    Vmax(ii) = max(pulse);
    % Signal generation
    Signal  = zeros(1,round(SigDuration/Tres));
    index   = 1:round(PRP/Tres):length(Signal);
    if dithering & length(index)>1,
        % Random Position (TH)
        index = index + round( rand(1,length(index)) * (index(2) - index(1)) );
        % Random Polarity
        Signal(index) = sign(randn(1,length(index)));
    else
        Signal(index) = 1;
    end
    Signal = conv(Signal,pulse);

    % Peak Power Measurement
    [Pp(ii), FM(ii)] = PeakMeasurement(Signal, Tres, VBW, RBW);
end
toc
close(ww)

Pp(1)-Pa(1)

break
%% Plots
figure(1),
subplot(2,2,1)
semilogx(PRF/1e6, Pa, PRF/1e6, AvLimit, 'r--' );
title('Average Power'), ylabel('[dBm]'), xlabel('PRF [MHz]'), grid
subplot(2,2,2)
semilogx(PRF/1e6, Pp, PRF/1e6, PkLimit, 'r--' );
title('Peak Power'), ylabel('[dBm]'), xlabel('PRF [MHz]'), grid
subplot(2,2,3:4)
semilogx(PRF/1e6, Pp-Pa);
title(['Peak to Average Ratio - RBW = ' num2str(RBW/1e6) 'MHz']),
ylabel('[dB]'), xlabel('PRF [MHz]'), grid

figure(2)
semilogx(PRF/1e6, Pp, PRF/1e6, PkLimit, 'r--' );
title(['Peak Power - RBW = ' num2str(RBW/1e6) 'MHz']), ylabel('[dBm]'), xlabel('PRF [MHz]'), grid
legend('Peak Measurement', 'FCC Limit')

figure(3),
semilogx(PRF/1e6, FM/1e9);
title(['F_M vs. PRF ']), grid
xlabel('PRF [MHz]'), ylabel('F_M [GHz]');
